@@ -1,13 +1,15 @@
 import * as React from 'react';
-import { get } from 'lodash';
 import {
   PodStatus,
   calculateRadius,
   getPodData,
   podRingLabel,
   podDataInProgress,
+  hpaPodRingLabel,
 } from '@console/shared';
+import { RevisionModel } from '@console/knative-plugin/src/models';
 import { DonutStatusData } from '../../topology-types';
+import { useRelatedHPA } from '../../../hpa/hooks';
 
 interface PodSetProps {
   size: number;
@@ -67,8 +69,19 @@ const PodSet: React.FC<PodSetProps> = ({ size, data, x = 0, y = 0, showPodCount
     data.isRollingOut,
   );
 
-  const obj = get(data, ['current', 'obj'], null) || data.dc;
-  const { title, subTitle, titleComponent } = podRingLabel(obj, data.dc.kind, data?.pods);
+  const [hpa] = useRelatedHPA(
+    data.dc.apiVersion,
+    data.dc.kind,
+    data.dc.metadata.name,
+    data.dc.metadata.namespace,
+  );
+  const hpaControlledScaling = !!hpa;
+
+  const obj = data.current?.obj || data.dc;
+  const ownerKind = RevisionModel.kind === data.dc?.kind ? data.dc.kind : obj.kind;
+  const { title, subTitle, titleComponent } = hpaControlledScaling
+    ? hpaPodRingLabel(obj, hpa, data?.pods)
+    : podRingLabel(obj, ownerKind, data?.pods);
   return (
     <>
       <PodStatus
